==> scala-k8s-objects_2.13-0.2.0-sources.jar: io/k8s/api/core/v1/ResourceRequirements.scala <==
package io.k8s.api.core.v1


/** ResourceRequirements describes the compute resource requirements. */
final case class ResourceRequirements(
  limits : Option[Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]] = None,
  requests : Option[Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]] = None
) {

  /** Returns a new data with limits set to new value */
  def withLimits(value: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(limits = Some(value))
  /** Adds new values to limits */
  def addLimits(newValues: (String, io.k8s.apimachinery.pkg.api.resource.Quantity)*) : ResourceRequirements = copy(limits = Some(limits.fold(newValues.toMap)(_ ++ newValues)))
  /** if limits has a value, transforms to the result of function*/
  def mapLimits(f: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity] => Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(limits = limits.map(f))

  /** Returns a new data with requests set to new value */
  def withRequests(value: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(requests = Some(value))
  /** Adds new values to requests */
  def addRequests(newValues: (String, io.k8s.apimachinery.pkg.api.resource.Quantity)*) : ResourceRequirements = copy(requests = Some(requests.fold(newValues.toMap)(_ ++ newValues)))
  /** if requests has a value, transforms to the result of function*/
  def mapRequests(f: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity] => Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(requests = requests.map(f))
}

==> scala-k8s-objects_3-0.5.1-sources.jar: io/k8s/api/core/v1/ResourceRequirements.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** ResourceRequirements describes the compute resource requirements. */
final case class ResourceRequirements(
  limits : Option[Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]] = None,
  requests : Option[Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]] = None
) {

  /** Returns a new data with limits set to new value */
  def withLimits(value: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(limits = Some(value))
  /** Adds new values to limits */
  def addLimits(newValues: (String, io.k8s.apimachinery.pkg.api.resource.Quantity)*) : ResourceRequirements = copy(limits = Some(limits.fold(newValues.toMap)(_ ++ newValues)))
  /** if limits has a value, transforms to the result of function*/
  def mapLimits(f: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity] => Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(limits = limits.map(f))

  /** Returns a new data with requests set to new value */
  def withRequests(value: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(requests = Some(value))
  /** Adds new values to requests */
  def addRequests(newValues: (String, io.k8s.apimachinery.pkg.api.resource.Quantity)*) : ResourceRequirements = copy(requests = Some(requests.fold(newValues.toMap)(_ ++ newValues)))
  /** if requests has a value, transforms to the result of function*/
  def mapRequests(f: Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity] => Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]) : ResourceRequirements = copy(requests = requests.map(f))
}

object ResourceRequirements {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ResourceRequirements] = new Encoder[io.k8s.api.core.v1.ResourceRequirements] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ResourceRequirements) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("limits", o.limits)
            .write("requests", o.requests)
            .build
        }
    }

    implicit val decoder: Decoder[ResourceRequirements] = new Decoder[ResourceRequirements] {
      def apply[T : Reader](t: T): Either[String, ResourceRequirements] = for {
          obj <- ObjectReader(t)
          limits <- obj.readOpt[Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]]("limits")
          requests <- obj.readOpt[Map[String, io.k8s.apimachinery.pkg.api.resource.Quantity]]("requests")
      } yield ResourceRequirements (
          limits = limits,
          requests = requests
        )
    }
}
